@@ -6,25 +6,11 @@ import logging
 import zlib
 from asyncio import QueueFull
 from collections import Counter
+from collections.abc import Awaitable, Callable, Coroutine, Iterator, Mapping, Sequence
 from datetime import datetime
 from enum import Enum
 from functools import partial
-from typing import (
-    Any,
-    Awaitable,
-    Callable,
-    Coroutine,
-    Dict,
-    FrozenSet,
-    Iterator,
-    List,
-    Mapping,
-    Optional,
-    Sequence,
-    Tuple,
-    Union,
-    cast,
-)
+from typing import Any, Optional, Union, cast
 
 import pandas as pd
 import pyarrow as pa
@@ -83,7 +69,7 @@ class Dataset(V1RoutesBaseModel):
     id: str
     name: str
     description: Optional[str]
-    metadata: Dict[str, Any]
+    metadata: dict[str, Any]
     created_at: datetime
     updated_at: datetime
 
@@ -246,7 +232,7 @@ async def get_dataset(
 class DatasetVersion(V1RoutesBaseModel):
     version_id: str
     description: Optional[str]
-    metadata: Dict[str, Any]
+    metadata: dict[str, Any]
     created_at: datetime
 
 
@@ -522,16 +508,16 @@ class FileContentEncoding(Enum):
 
 Name: TypeAlias = str
 Description: TypeAlias = Optional[str]
-InputKeys: TypeAlias = FrozenSet[str]
-OutputKeys: TypeAlias = FrozenSet[str]
-MetadataKeys: TypeAlias = FrozenSet[str]
+InputKeys: TypeAlias = frozenset[str]
+OutputKeys: TypeAlias = frozenset[str]
+MetadataKeys: TypeAlias = frozenset[str]
 DatasetId: TypeAlias = int
 Examples: TypeAlias = Iterator[ExampleContent]
 
 
 def _process_json(
     data: Mapping[str, Any],
-) -> Tuple[Examples, DatasetAction, Name, Description]:
+) -> tuple[Examples, DatasetAction, Name, Description]:
     name = data.get("name")
     if not name:
         raise ValueError("Dataset name is required")
@@ -547,7 +533,7 @@ def _process_json(
             raise ValueError(
                 f"{k} should be a list of same length as input containing only dictionary objects"
             )
-    examples: List[ExampleContent] = []
+    examples: list[ExampleContent] = []
     for i, obj in enumerate(inputs):
         example = ExampleContent(
             input=obj,
@@ -623,7 +609,7 @@ async def _check_table_exists(session: AsyncSession, name: str) -> bool:
 
 
 def _check_keys_exist(
-    column_headers: FrozenSet[str],
+    column_headers: frozenset[str],
     input_keys: InputKeys,
     output_keys: OutputKeys,
     metadata_keys: MetadataKeys,
@@ -639,7 +625,7 @@ def _check_keys_exist(
 
 async def _parse_form_data(
     form: FormData,
-) -> Tuple[
+) -> tuple[
     DatasetAction,
     Name,
     Description,
@@ -656,9 +642,9 @@ async def _parse_form_data(
     if not isinstance(file, UploadFile):
         raise ValueError("Malformed file in form data.")
     description = cast(Optional[str], form.get("description")) or file.filename
-    input_keys = frozenset(filter(bool, cast(List[str], form.getlist("input_keys[]"))))
-    output_keys = frozenset(filter(bool, cast(List[str], form.getlist("output_keys[]"))))
-    metadata_keys = frozenset(filter(bool, cast(List[str], form.getlist("metadata_keys[]"))))
+    input_keys = frozenset(filter(bool, cast(list[str], form.getlist("input_keys[]"))))
+    output_keys = frozenset(filter(bool, cast(list[str], form.getlist("output_keys[]"))))
+    metadata_keys = frozenset(filter(bool, cast(list[str], form.getlist("metadata_keys[]"))))
     return (
         action,
         name,
@@ -672,16 +658,16 @@ async def _parse_form_data(
 
 class DatasetExample(V1RoutesBaseModel):
     id: str
-    input: Dict[str, Any]
-    output: Dict[str, Any]
-    metadata: Dict[str, Any]
+    input: dict[str, Any]
+    output: dict[str, Any]
+    metadata: dict[str, Any]
     updated_at: datetime
 
 
 class ListDatasetExamplesData(V1RoutesBaseModel):
     dataset_id: str
     version_id: str
-    examples: List[DatasetExample]
+    examples: list[DatasetExample]
 
 
 class ListDatasetExamplesResponseBody(ResponseBody[ListDatasetExamplesData]):
@@ -914,7 +900,7 @@ async def get_dataset_jsonl_openai_evals(
     return content
 
 
-def _get_content_csv(examples: List[models.DatasetExampleRevision]) -> bytes:
+def _get_content_csv(examples: list[models.DatasetExampleRevision]) -> bytes:
     records = [
         {
             "example_id": GlobalID(
@@ -930,28 +916,31 @@ def _get_content_csv(examples: List[models.DatasetExampleRevision]) -> bytes:
     return str(pd.DataFrame.from_records(records).to_csv(index=False)).encode()
 
 
-def _get_content_jsonl_openai_ft(examples: List[models.DatasetExampleRevision]) -> bytes:
+def _get_content_jsonl_openai_ft(examples: list[models.DatasetExampleRevision]) -> bytes:
     records = io.BytesIO()
     for ex in examples:
-        records.write(
-            (
-                json.dumps(
-                    {
-                        "messages": (
-                            ims if isinstance(ims := ex.input.get("messages"), list) else []
-                        )
-                        + (oms if isinstance(oms := ex.output.get("messages"), list) else [])
-                    },
-                    ensure_ascii=False,
-                )
-                + "\n"
-            ).encode()
-        )
+        input_messages = ex.input.get("messages", [])
+        if not isinstance(input_messages, list):
+            input_messages = []
+        output_messages = ex.output.get("messages", [])
+        if not isinstance(output_messages, list):
+            output_messages = []
+
+        record_dict = {
+            "messages": input_messages + output_messages,
+        }
+
+        tools = ex.input.get("tools", [])
+        if tools:
+            record_dict["tools"] = tools
+
+        records.write((json.dumps(record_dict, ensure_ascii=False) + "\n").encode())
+
     records.seek(0)
     return records.read()
 
 
-def _get_content_jsonl_openai_evals(examples: List[models.DatasetExampleRevision]) -> bytes:
+def _get_content_jsonl_openai_evals(examples: list[models.DatasetExampleRevision]) -> bytes:
     records = io.BytesIO()
     for ex in examples:
         records.write(
@@ -980,7 +969,7 @@ def _get_content_jsonl_openai_evals(examples: List[models.DatasetExampleRevision
 
 async def _get_db_examples(
     *, session: Any, id: str, version_id: Optional[str]
-) -> Tuple[str, List[models.DatasetExampleRevision]]:
+) -> tuple[str, list[models.DatasetExampleRevision]]:
     dataset_id = from_global_id_with_expected_type(GlobalID.from_id(id), DATASET_NODE_NAME)
     dataset_version_id: Optional[int] = None
     if version_id:
