@@ -1,5 +1,3 @@
-from typing import List
-
 from sqlalchemy import delete
 
 from phoenix.db import models
@@ -9,7 +7,7 @@ from phoenix.server.types import DbSessionFactory
 async def delete_projects(
     db: DbSessionFactory,
     *project_names: str,
-) -> List[int]:
+) -> list[int]:
     if not project_names:
         return []
     stmt = (
@@ -24,7 +22,7 @@ async def delete_projects(
 async def delete_traces(
     db: DbSessionFactory,
     *trace_ids: str,
-) -> List[int]:
+) -> list[int]:
     if not trace_ids:
         return []
     stmt = (
